@@ -2,7 +2,7 @@
 #define FPSUBMIT_CONSTANTS_H_
 
 static const char *API_KEY_URL = "http://acoustid.org/api-key";
-static const char *SUBMIT_URL = "http://api.acoustid.org/submit";
+static const char *SUBMIT_URL = "http://api.acoustid.org/v2/submit";
 //static const char *SUBMIT_URL = "http://127.0.0.1:8080/ws/submit";
 static const char *CLIENT_API_KEY = "cvJ31mD0"; 
 static const int AUDIO_LENGTH = 120;
