@@ -3,9 +3,11 @@
 #include <QUrl>
 #include <QNetworkReply>
 #include <QNetworkRequest>
-#include <QtConcurrentRun>
+#include <QNetworkProxy>
+#include <QNetworkProxyFactory>
 #include <QDesktopServices>
 #include <QMutexLocker>
+#include <QThreadPool>
 #include "loadfilelisttask.h"
 #include "analyzefiletask.h"
 #include "updatelogfiletask.h"
@@ -14,11 +16,54 @@
 #include "utils.h"
 #include "gzip.h"
 
+class NetworkProxyFactory : public QNetworkProxyFactory
+{
+public:
+	NetworkProxyFactory() : m_httpProxy(QNetworkProxy::NoProxy)
+	{
+		char* httpProxyUrl = getenv("http_proxy");
+		if (httpProxyUrl) {
+			QUrl url = QUrl::fromEncoded(QByteArray(httpProxyUrl));
+			if (url.isValid() && !url.host().isEmpty()) {
+				m_httpProxy = QNetworkProxy(QNetworkProxy::HttpProxy, url.host(), url.port(80));
+				if (!url.userName().isEmpty())	{
+					m_httpProxy.setUser(url.userName());
+					if (!url.password().isEmpty()) {
+						m_httpProxy.setPassword(url.password());
+					}
+				}
+			}
+		}
+	}
+
+	QList<QNetworkProxy> queryProxy(const QNetworkProxyQuery& query)
+	{
+		QList<QNetworkProxy> proxies = QNetworkProxyFactory::systemProxyForQuery(query);
+		QString protocol = query.protocolTag().toLower();
+		if (m_httpProxy.type() != QNetworkProxy::NoProxy && protocol == QLatin1String("http")) {
+			QMutableListIterator<QNetworkProxy> i(proxies);
+			while (i.hasNext()) {
+				QNetworkProxy& proxy = i.next();
+				if (proxy.type() == QNetworkProxy::NoProxy) {
+					i.remove();
+				}
+			}
+			proxies.append(m_httpProxy);
+			proxies.append(QNetworkProxy::NoProxy);
+		}
+		return proxies;
+	}
+
+private:
+	QNetworkProxy m_httpProxy;
+};
+
 Fingerprinter::Fingerprinter(const QString &apiKey, const QStringList &directories)
     : m_apiKey(apiKey), m_directories(directories), m_paused(false), m_cancelled(false),
 	  m_finished(false), m_reply(0), m_activeFiles(0), m_fingerprintedFiles(0), m_submittedFiles(0)
 {
 	m_networkAccessManager = new QNetworkAccessManager(this);
+	m_networkAccessManager->setProxyFactory(new NetworkProxyFactory());
 	connect(m_networkAccessManager, SIGNAL(finished(QNetworkReply *)), SLOT(onRequestFinished(QNetworkReply*)));
 }
 
@@ -150,13 +195,13 @@ bool Fingerprinter::maybeSubmit(bool force)
 			AnalyzeResult *result = m_submitQueue.takeFirst();
 			qDebug() << "  " << result->mbid;
 			url.addQueryItem(QString("duration.%1").arg(i), QString::number(result->length));
+			if (!result->puid.isEmpty()) {
+				url.addQueryItem(QString("puid.%1").arg(i), result->puid);
+			}
 			if (!result->mbid.isEmpty()) {
 				url.addQueryItem(QString("mbid.%1").arg(i), result->mbid);
 			}
 			else {
-				if (!result->puid.isEmpty()) {
-					url.addQueryItem(QString("puid.%1").arg(i), result->puid);
-				}
 				if (!result->track.isEmpty()) {
 					url.addQueryItem(QString("track.%1").arg(i), result->track);
 				}
@@ -182,7 +227,7 @@ bool Fingerprinter::maybeSubmit(bool force)
 			url.addQueryItem(QString("fingerprint.%1").arg(i), result->fingerprint);
 			QString format = extractExtension(result->fileName);
 			if (!format.isEmpty()) {
-				url.addQueryItem(QString("format.%1").arg(i), format);
+				url.addQueryItem(QString("fileformat.%1").arg(i), format);
 			}
 			if (result->bitrate) {
 				url.addQueryItem(QString("bitrate.%1").arg(i), QString::number(result->bitrate));
